@@ -70,9 +70,12 @@ const uint64_t n_shapes_cache[MAX_SHAPE_TIP + 1] = {
 };
 
 uint64_t n_shapes(intx n_tips) {
+  if (n_tips < 0) {
+    Rcpp::stop("Tree must have at least zero leaves");
+  }
   if (n_tips > 55) {
-    Rcpp::stop("64 bit integers cannot represent number of shapes"
-               "for > 55 tips");
+    Rcpp::stop("64 bit integers cannot represent number of shapes "
+               "for > 55 leaves");
   }
   return n_shapes_cache[n_tips];
 }
